@@ -4,7 +4,7 @@ from httpx import AsyncClient
 
 from pydantic import ValidationError as PydanticValidationError
 
-from paddle.client import BearerAuth
+from paddle.auth import BearerAuth
 from paddle.schemas import (
     Status,
     Customer1,
@@ -14,7 +14,7 @@ from paddle.schemas import (
     CreditBalance,
     CustomerAuthenticationToken,
 )
-from paddle.schemas.response import Response, PaginatedResponse
+from paddle.schemas.human.response import Response, PaginatedResponse
 from paddle.exceptions import ValidationError, ApiError
 
 
@@ -25,8 +25,9 @@ OrderBy = Literal[
 
 
 class CustomerOperationsMixin:
-    token: str
-    client: AsyncClient
+    _token: str
+    _client: AsyncClient
+    _endpoint: str
 
     async def list_customers(
         self,
@@ -41,7 +42,7 @@ class CustomerOperationsMixin:
     ) -> PaginatedResponse[Customer1]:
         """List customers."""
 
-        url = "https://api.paddle.com/customers"
+        url = f"https://{self._endpoint}/customers"
 
         query = {}
 
@@ -67,17 +68,21 @@ class CustomerOperationsMixin:
             query["status"] = status.value
 
         try:
-            response = await self.client.get(
+            response = await self._client.get(
                 url,
                 params=query,
-                auth=BearerAuth(self.token),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return PaginatedResponse[Customer1].model_validate_json(response.text)
 
@@ -90,20 +95,26 @@ class CustomerOperationsMixin:
     ) -> Response[Customer1]:
         """Create a new customer."""
 
-        url = "https://api.paddle.com/customers"
+        url = f"https://{self._endpoint}/customers"
 
         try:
-            response = await self.client.post(
+            response = await self._client.post(
                 url,
-                json=customer.model_dump(mode="json"),
-                auth=BearerAuth(self.token),
+                json=customer.model_dump(
+                    mode="json", exclude_unset=True, exclude_defaults=True
+                ),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return Response[Customer1].model_validate_json(response.text)
 
@@ -116,19 +127,23 @@ class CustomerOperationsMixin:
     ) -> Response[Customer1]:
         """Retrieve a specific customer by ID."""
 
-        url = f"https://api.paddle.com/customers/{customer_id}"
+        url = f"https://{self._endpoint}/customers/{customer_id}"
 
         try:
-            response = await self.client.get(
+            response = await self._client.get(
                 url,
-                auth=BearerAuth(self.token),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return Response[Customer1].model_validate_json(response.text)
 
@@ -142,20 +157,24 @@ class CustomerOperationsMixin:
     ) -> Response[Customer1]:
         """Update a specific customer by ID."""
 
-        url = f"https://api.paddle.com/customers/{customer_id}"
+        url = f"https://{self._endpoint}/customers/{customer_id}"
 
         try:
-            response = await self.client.put(
+            response = await self._client.put(
                 url,
                 json=customer.model_dump(mode="json"),
-                auth=BearerAuth(self.token),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return Response[Customer1].model_validate_json(response.text)
 
@@ -170,7 +189,7 @@ class CustomerOperationsMixin:
     ) -> Response[CreditBalance]:
         """Retrieve credit balances for a specific customer."""
 
-        url = f"https://api.paddle.com/customers/{customer_id}/credit-balances"
+        url = f"https://{self._endpoint}/customers/{customer_id}/credit-balances"
 
         query = {}
 
@@ -178,17 +197,21 @@ class CustomerOperationsMixin:
             query["currency_codes"] = ",".join([code.value for code in currency_codes])
 
         try:
-            response = await self.client.get(
+            response = await self._client.get(
                 url,
                 params=query,
-                auth=BearerAuth(self.token),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return Response[CreditBalance].model_validate_json(response.text)
 
@@ -201,19 +224,23 @@ class CustomerOperationsMixin:
     ) -> Response[CustomerAuthenticationToken]:
         """Create an authentication token for a specific customer."""
 
-        url = f"https://api.paddle.com/customers/{customer_id}/auth-token"
+        url = f"https://{self._endpoint}/customers/{customer_id}/auth-token"
 
         try:
-            response = await self.client.post(
+            response = await self._client.post(
                 url,
-                auth=BearerAuth(self.token),
+                auth=BearerAuth(self._token),
             )
 
-            response.raise_for_status()
-
         except Exception as e:
             raise ApiError from e
 
+        try:
+            response.raise_for_status()
+
+        except Exception as e:
+            raise ApiError(response.text) from e
+
         try:
             return Response[CustomerAuthenticationToken].model_validate_json(
                 response.text
